hardlinkdeduplicator

package module
v0.0.0-...-04e405c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 16, 2024 License: AGPL-3.0 Imports: 8 Imported by: 0

README

Overview

HardLink Deduplicator is a tool for detecting and managing duplicate files on your system by utilizing hard links. It helps in reducing storage space usage by creating hard links between identical files.

Features

  • Detect and report duplicate files.
  • Deduplicate files by creating hard links.
  • Option to keep only one extra copy of the file or remove all duplicates.
  • Minimum file size setting to consider for deduplication.

Installation

Prerequisites
  • Supported operating systems: Windows
  • Go version 1.14 or higher
Installation Steps
  1. Clone the repository:
git clone https://github.com/NIR3X/hardlinkdeduplicator
  1. Change to the project directory:
cd hardlinkdeduplicator
  1. Build the project:
go build -o hardlinkdeduplicator.exe .\cmd\hardlinkdeduplicator
  1. Run the executable:
.\hardlinkdeduplicator -h

Usage

.\hardlinkdeduplicator [options] path

Options

  • -a: Remove all duplicates (default is to keep one extra copy of the file).
  • -d: Deduplicate files (not just report duplicates).
  • -s: Minimum file size to consider for deduplication (in bytes).
  • -v: Verbose output.

Example

.\hardlinkdeduplicator -a -d -s 1024 -v C:\Path\To\Directory

License

GNU AGPLv3 Image

This program is Free Software: You can use, study share and improve it at your will. Specifically you can redistribute and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Deduplicate

func Deduplicate(path string, all, deduplicate bool, minSize int64, verbose bool)

Types

This section is empty.

Directories

Path Synopsis
cmd

Jump to